AutoArchive._infrastructure.utils — AutoArchive Developer Manual (ver. 2.1.0.dev20260309)

# AutoArchive._infrastructure.utils

Common helpers.

## Sub-Packages

- AutoArchive._infrastructure.utils.interval

## Modules

### constants

class AutoArchive._infrastructure.utils.constants.Constants

  Bases: `object`

  Defines various “global” constants.

  DEBUG = None

    Debugging support.

  TEMP_FILE_PREFIX = 'autoarchive'

    Prefix for names of temporary files

### error_handling

class AutoArchive._infrastructure.utils.error_handling.ErrorHandling

  Bases: `object`

  classmethod fatalExit(msg, appName=None)

    Prints `msg` to standard error and exits with exit code 2.

  classmethod printError(msg, appName=None)

    Prints `msg` as an error to standard error.

  classmethod printWarning(msg, appName=None)

    Prints `msg` as a warning to standard error.

### os_paths

`OsPaths`.

class AutoArchive._infrastructure.utils.os_paths.OsPaths

  Bases: `object`

  Provides OS-specific paths

  classmethod getSystemConfigDir() → str
  classmethod getUserConfigDir() → str
  classmethod getUserDataDir() → str

### utils

class AutoArchive._infrastructure.utils.utils.Utils

  Bases: `object`

  Various utility methods.

  static effectiveAccess(path, mode)
  static getKeysForValue(value: __V, mapping: Mapping[__K, __V]) → Iterable[__K]

    Returns keys of `mapping` which has value equal to `value`

  static isWindows()
  static uniq(decorated)

    Decorator that filters out duplicate elements from an iterable returned by decorated function.